@@ -859,16 +859,17 @@ ebbm_contacts_get_status_message (EBookBackendMAPI *ebma, gint index, gint total
 	if (index <= 0)
 		return NULL;
 
-	return g_strdup_printf (
-		total <= 0 ?
+	if (total <= 0)
+		return g_strdup_printf (
 			/* Translators : This is used to cache the downloaded contacts from a server.
 			   %d is an index of the contact. */
-			_("Caching contact %d") :
-			/* Translators : This is used to cache the downloaded contacts from a server.
-			   The first %d is an index of the contact,
-			   the second %d is total count of conacts on the server. */
-			_("Caching contact %d/%d"),
-		index, total);
+			_("Caching contact %d"), index);
+
+	return g_strdup_printf (
+		/* Translators : This is used to cache the downloaded contacts from a server.
+		   The first %d is an index of the contact,
+		   the second %d is total count of conacts on the server. */
+		_("Caching contact %d/%d"), index, total);
 }
 
 static void
